
widget_code_input
=====================================

Version: |release|

A widget to allow input of a python function, with syntax highlighting.


Quickstart
----------

To get started with widget_code_input, install with pip::

    pip install widget_code_input

or with conda::

    conda install widget_code_input


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/
